COMPMID-630: Rework nodes

Reworked node:
-BatchNormalization
-Floor
-FullyConncted
-L2Normalize
-Normalization
-Pooling
-Softmax

Change-Id: I4c71cfffb1f59aac3326ba8b1f831339c5244394
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/93134
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/arm_compute/graph/NodeContext.h b/arm_compute/graph/NodeContext.h
index 8e8a761..bc90f21 100644
--- a/arm_compute/graph/NodeContext.h
+++ b/arm_compute/graph/NodeContext.h
@@ -45,11 +45,10 @@
 {
 public:
     /** Default Constructor
-     * (TODO(geopin01): Should we have an enum with all the supported ops instead?)
      *
      * @param[in] operation Name of the operation
      */
-    NodeContext(std::string operation)
+    NodeContext(OperationType operation)
         : _operation(operation), _target(TargetHint::DONT_CARE), _inputs(), _outputs(), _parameters() {};
     /** Sets the execution target of the node
      *
@@ -75,9 +74,9 @@
     void add_parameter(std::string name, T parameter);
     /** Returns the operation of this node.
      *
      * @return The operation name
      */
-    std::string operation() const;
+    OperationType operation() const;
     /** Returns the execution target of this node
      *
      * @return The execution target
@@ -117,7 +116,7 @@
     size_t num_outputs() const;
 
 private:
-    std::string                         _operation;
+    OperationType                       _operation;
     TargetHint                          _target;
     std::vector<arm_compute::ITensor *> _inputs;
     std::vector<arm_compute::ITensor *> _outputs;
@@ -75,9 +74,9 @@
     /** Returns the operation of this node.
      *
-     * @return The operation name
+     * @return The operation type
      */